CrdtSchemaColumnAttachRowRepository class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tbl(DatabaseSession session, CrdtSchemaColumn crdtSchemaColumn, CrdtSchemaTable tbl, {Transaction? transaction}) Future<void>
Creates a relation between the given CrdtSchemaColumn and CrdtSchemaTable by setting the CrdtSchemaColumn's foreign key tblId to refer to the CrdtSchemaTable.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited