CrdtSchemaTableRepository class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
count(DatabaseSession session, {WhereExpressionBuilder<CrdtSchemaTableTable>? where, int? limit, Transaction? transaction})
→ Future<int>
-
Counts the number of rows matching the
where expression. If omitted,
will return the count of all rows in the table.
-
delete(DatabaseSession session, List<CrdtSchemaTable> rows, {OrderByBuilder<CrdtSchemaTableTable>? orderBy, OrderByListBuilder<CrdtSchemaTableTable>? orderByList, Transaction? transaction, bool noReturn = false})
→ Future<List<CrdtSchemaTable>>
-
Deletes all CrdtSchemaTables in the list and returns the deleted rows.
-
deleteRow(DatabaseSession session, CrdtSchemaTable row, {Transaction? transaction})
→ Future<CrdtSchemaTable>
-
Deletes a single CrdtSchemaTable.
-
deleteWhere(DatabaseSession session, {required WhereExpressionBuilder<CrdtSchemaTableTable> where, OrderByBuilder<CrdtSchemaTableTable>? orderBy, OrderByListBuilder<CrdtSchemaTableTable>? orderByList, Transaction? transaction, bool noReturn = false})
→ Future<List<CrdtSchemaTable>>
-
Deletes all rows matching the
where expression.
-
find(DatabaseSession session, {WhereExpressionBuilder<CrdtSchemaTableTable>? where, int? limit, int? offset, OrderByBuilder<CrdtSchemaTableTable>? orderBy, OrderByListBuilder<CrdtSchemaTableTable>? orderByList, Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<List<CrdtSchemaTable>>
-
Returns a list of CrdtSchemaTables matching the given query parameters.
-
findById(DatabaseSession session, int id, {Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<CrdtSchemaTable?>
-
Finds a single CrdtSchemaTable by its
id or null if no such row exists.
-
findFirstRow(DatabaseSession session, {WhereExpressionBuilder<CrdtSchemaTableTable>? where, int? offset, OrderByBuilder<CrdtSchemaTableTable>? orderBy, OrderByListBuilder<CrdtSchemaTableTable>? orderByList, Transaction? transaction, LockMode? lockMode, LockBehavior? lockBehavior})
→ Future<CrdtSchemaTable?>
-
Returns the first matching CrdtSchemaTable matching the given query parameters.
-
insert(DatabaseSession session, List<CrdtSchemaTable> rows, {Transaction? transaction, bool ignoreConflicts = false, bool noReturn = false})
→ Future<List<CrdtSchemaTable>>
-
Inserts all CrdtSchemaTables in the list and returns the inserted rows.
-
insertRow(DatabaseSession session, CrdtSchemaTable row, {Transaction? transaction})
→ Future<CrdtSchemaTable>
-
Inserts a single CrdtSchemaTable and returns the inserted row.
-
lockRows(DatabaseSession session, {required WhereExpressionBuilder<CrdtSchemaTableTable> where, required LockMode lockMode, required Transaction transaction, LockBehavior lockBehavior = _isd.LockBehavior.wait})
→ Future<void>
-
Acquires row-level locks on CrdtSchemaTable rows matching the
where expression.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(DatabaseSession session, List<CrdtSchemaTable> rows, {ColumnSelections<CrdtSchemaTableTable>? columns, Transaction? transaction, bool noReturn = false})
→ Future<List<CrdtSchemaTable>>
-
Updates all CrdtSchemaTables in the list and returns the updated rows. If
columns is provided, only those columns will be updated. Defaults to
all columns.
This is an atomic operation, meaning that if one of the rows fails to
update, none of the rows will be updated.
-
updateById(DatabaseSession session, int id, {required ColumnValueListBuilder<CrdtSchemaTableUpdateTable> columnValues, Transaction? transaction})
→ Future<CrdtSchemaTable?>
-
Updates a single CrdtSchemaTable by its
id with the specified columnValues.
Returns the updated row or null if no row with the given id exists.
-
updateRow(DatabaseSession session, CrdtSchemaTable row, {ColumnSelections<CrdtSchemaTableTable>? columns, Transaction? transaction})
→ Future<CrdtSchemaTable>
-
Updates a single CrdtSchemaTable. The row needs to have its id set.
Optionally, a list of
columns can be provided to only update those
columns. Defaults to all columns.
-
updateWhere(DatabaseSession session, {required ColumnValueListBuilder<CrdtSchemaTableUpdateTable> columnValues, required WhereExpressionBuilder<CrdtSchemaTableTable> where, int? limit, int? offset, OrderByBuilder<CrdtSchemaTableTable>? orderBy, OrderByListBuilder<CrdtSchemaTableTable>? orderByList, Transaction? transaction, bool noReturn = false})
→ Future<List<CrdtSchemaTable>>
-
Updates all CrdtSchemaTables matching the
where expression with the specified columnValues.
Returns the list of updated rows.
-
upsert(DatabaseSession session, List<CrdtSchemaTable> rows, {required ColumnSelections<CrdtSchemaTableTable> conflictColumns, ColumnSelections<CrdtSchemaTableTable>? updateColumns, WhereExpressionBuilder<CrdtSchemaTableTable>? updateWhere, Transaction? transaction, bool noReturn = false})
→ Future<List<CrdtSchemaTable>>
-
Upserts all CrdtSchemaTables in the list and returns the resulting rows.
-
upsertRow(DatabaseSession session, CrdtSchemaTable row, {required ColumnSelections<CrdtSchemaTableTable> conflictColumns, ColumnSelections<CrdtSchemaTableTable>? updateColumns, WhereExpressionBuilder<CrdtSchemaTableTable>? updateWhere, Transaction? transaction})
→ Future<CrdtSchemaTable?>
-
Upserts a single CrdtSchemaTable and returns the resulting row.