CrdtDataRowTable class
Constructors
- CrdtDataRowTable({TableRelation? tableRelation})
Properties
-
columns
→ List<
Column> -
List of
Columnused by the table.no setter - deleted → CrdtDataDeletedTable
-
no setter
-
fields
→ ManyRelation<
CrdtDataFieldTable> -
no setter
- hasColumnMapping → bool
-
Cached flag indicating whether any columns have explicit column names
that differ from their field names. Computed lazily on first access.
latefinalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hlcCounter ↔ ColumnInt
-
The counter component of the HLC timestamp.
latefinal
- hlcDatetime ↔ ColumnDateTime
-
The datetime component of the HLC timestamp.
latefinal
-
id
↔ ColumnComparable<
int?> -
The database id.
latefinalinherited
-
managedColumns
→ List<
Column> -
List of
Columnthat are managed by this table. This is mostly used to exclude columns created by implicit relations.no setterinherited - node → CrdtNodeTable
-
no setter
- nodeId ↔ ColumnInt
-
latefinal
- queryPrefix → String
-
Query prefix for
Columns of the table.no setterinherited - quotedTableName → String
-
tableNamequoted for the current dialect. Prefer it overtableNamein raw SQL, since dialects quote schemas differently.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schema → String?
-
Schema part of
tableName, or null when the name is unqualified.latefinalinherited - space → OfflineSyncSpaceTable
-
no setter
- spaceId ↔ ColumnInt
-
latefinal
- tableName → String
-
Name of the table as used in the database, optionally qualified as
schema.table.finalinherited - tableRelation → TableRelation?
-
Table relation for
Columns of the table.finalinherited - tbl → CrdtSchemaTableTable
-
no setter
- tblId ↔ ColumnInt
-
latefinal
- unqualifiedTableName → String
-
tableNamewith the schema removed.latefinalinherited - updateTable ↔ CrdtDataRowUpdateTable
-
latefinal
- uuidRowId ↔ ColumnUuid
-
Row identifier.
latefinal
-
visibility
↔ ColumnEnum<
CrdtDataRowVisibility> -
Materialized visibility state for domain queries.
latefinal
Methods
-
getRelationTable(
String relationField) → Table? -
Returns
TableColumnRelationfor the givenrelationField. If no relation exists, returns null. The return must be dynamic to allow for relations with different id types. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited